summaryrefslogtreecommitdiff
path: root/lib/sbin/ImpParamConsistency.pl
diff options
context:
space:
mode:
authorallen <allen@17b73243-c579-4c4c-a9d2-2d5706c11dac>1999-07-04 12:35:39 +0000
committerallen <allen@17b73243-c579-4c4c-a9d2-2d5706c11dac>1999-07-04 12:35:39 +0000
commitf421fdb9ca6ce5765f8bd4e568b94d29a534a296 (patch)
treece058fa87534134e87f6ec5c7d953afdcb5e0d53 /lib/sbin/ImpParamConsistency.pl
parent01f356b3dda9d3a4d857a1a0ebe58583dc55bbde (diff)
New names for parameter groups:
public -> global protected -> restricted private -> private friend -> shares (although we would like a better word for this) Can now use USES as well as EXTENDS (although both of them are optional ... perhaps they shouldn't be?). I would like to be able to get rid of the { } after USES but I couldn't manage it so far. git-svn-id: http://svn.cactuscode.org/flesh/trunk@632 17b73243-c579-4c4c-a9d2-2d5706c11dac
Diffstat (limited to 'lib/sbin/ImpParamConsistency.pl')
-rw-r--r--lib/sbin/ImpParamConsistency.pl12
1 files changed, 6 insertions, 6 deletions
diff --git a/lib/sbin/ImpParamConsistency.pl b/lib/sbin/ImpParamConsistency.pl
index 328677e8..e1fe5928 100644
--- a/lib/sbin/ImpParamConsistency.pl
+++ b/lib/sbin/ImpParamConsistency.pl
@@ -26,7 +26,7 @@ sub CheckImpParamConsistency
{
# print "Processing thorn $thorn\n";
- foreach $friend (split(" ", $parameter_database{"\U$thorn\E FRIEND implementations"}))
+ foreach $friend (split(" ", $parameter_database{"\U$thorn\E SHARES implementations"}))
{
# print "Friend is $friend\n";
# Find a thorn providing this implementation
@@ -34,15 +34,15 @@ sub CheckImpParamConsistency
# print "Other thorn is $other_thorn\n";
- foreach $parameter (split(" ", $parameter_database{"\U$thorn FRIEND $friend\E variables"}))
+ foreach $parameter (split(" ", $parameter_database{"\U$thorn SHARES $friend\E variables"}))
{
# print "Parameter is $parameter\n";
# Check if the parameter exists in the other thorn
if($parameter_database{"\U$other_thorn $parameter\E type"})
{
- # Check that the parameter is in the protected block.
- if($parameter_database{"\U$other_thorn PROTECTED\E variables"} =~ m:\b$parameter\b:i)
+ # Check that the parameter is in the restricted block.
+ if($parameter_database{"\U$other_thorn RESTRICTED\E variables"} =~ m:\b$parameter\b:i)
{
# Loop through all the added ranges.
for($range=1;
@@ -61,12 +61,12 @@ sub CheckImpParamConsistency
}
else
{
- print STDERR "Thorn $thorn attempted to EXTEND non-protected parameter $parameter from $friend\n";
+ print STDERR "Thorn $thorn attempted to EXTEND non-restricted parameter $parameter from $friend\n";
}
}
else
{
- print STDERR "Thorn $thorn attempted to EXTEND non-existent parameter $parameter from $friend\n";
+ print STDERR "Thorn $thorn attempted to EXTEND non-existant parameter $parameter from $friend\n";
}
}
}